==> muffin_0.9.orig.tar.gz: muffin-0.9/src/org/doit/muffin/filter/ForwardedForFilter.java <==
/* $Id: ForwardedForFilter.java,v 1.4 1999/03/12 15:47:42 boyns Exp $ */

/*
 * Copyright (C) 1996-99 Mark R. Boyns <boyns@doit.org>
 *
 * This file is part of Muffin.
 *
 * Muffin is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Muffin is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Muffin; see the file COPYING.  If not, write to the
 * Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package org.doit.muffin.filter;

import org.doit.muffin.*;

public class ForwardedForFilter implements RequestFilter
{
    Prefs prefs;
    ForwardedFor factory;

    ForwardedForFilter(ForwardedFor factory)
    {
	this.factory = factory;
    }
    
    public void setPrefs(Prefs prefs)
    {
	this.prefs = prefs;
    }

    public void filter(Request request) throws FilterException
    {
	String addr = request.getClient().getInetAddress().getHostAddress();
	if (request.containsHeaderField("X-Forwarded-For"))
	{
	    request.appendHeaderField("X-Forwarded-For", ", " + addr);
	}
	else
	{
	    request.setHeaderField("X-Forwarded-For", addr);
	}
    }
}

==> muffin_0.9.3a.orig.tar.gz: muffin-0.9.3a/src/org/doit/muffin/filter/ForwardedForFilter.java <==
/* $Id: ForwardedForFilter.java,v 1.6 2000/03/30 06:32:54 boyns Exp $ */

/*
 * Copyright (C) 1996-2000 Mark R. Boyns <boyns@doit.org>
 *
 * This file is part of Muffin.
 *
 * Muffin is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Muffin is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Muffin; see the file COPYING.  If not, write to the
 * Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 */
package org.doit.muffin.filter;

import org.doit.muffin.*;

public class ForwardedForFilter implements RequestFilter
{
    Prefs prefs;
    ForwardedFor factory;

    ForwardedForFilter(ForwardedFor factory)
    {
	this.factory = factory;
    }
    
    public void setPrefs(Prefs prefs)
    {
	this.prefs = prefs;
    }

    public void filter(Request request) throws FilterException
    {
	String addr = request.getClient().getInetAddress().getHostAddress();
	if (request.containsHeaderField("X-Forwarded-For"))
	{
	    request.appendHeaderField("X-Forwarded-For", ", " + addr);
	}
	else
	{
	    request.setHeaderFields("X-Forwarded-For", addr);
	}
    }
}
